(function ($) {
    'use strict';

    /*
     * Add integers, wrapping at 2^32. This uses 16-bit operations internally
     * to work around bugs in some JS interpreters.
     */
    function safe_add(x, y) {
        var lsw = (x & 0xFFFF) + (y & 0xFFFF),
            msw = (x >> 16) + (y >> 16) + (lsw >> 16);
        return (msw << 16) | (lsw & 0xFFFF);
    }

    /*
     * Bitwise rotate a 32-bit number to the left.
     */
    function bit_rol(num, cnt) {
        return (num << cnt) | (num >>> (32 - cnt));
    }

    /*
     * These functions implement the four basic operations the algorithm uses.
     */
    function md5_cmn(q, a, b, x, s, t) {
        return safe_add(bit_rol(safe_add(safe_add(a, q), safe_add(x, t)), s), b);
    }

    function md5_ff(a, b, c, d, x, s, t) {
        return md5_cmn((b & c) | ((~b) & d), a, b, x, s, t);
    }

    function md5_gg(a, b, c, d, x, s, t) {
        return md5_cmn((b & d) | (c & (~d)), a, b, x, s, t);
    }

    function md5_hh(a, b, c, d, x, s, t) {
        return md5_cmn(b ^ c ^ d, a, b, x, s, t);
    }

    function md5_ii(a, b, c, d, x, s, t) {
        return md5_cmn(c ^ (b | (~d)), a, b, x, s, t);
    }

    /*
     * Calculate the MD5 of an array of little-endian words, and a bit length.
     */
    function binl_md5(x, len) {
        /* append padding */
        x[len >> 5] |= 0x80 << ((len) % 32);
        x[(((len + 64) >>> 9) << 4) + 14] = len;

        var i, olda, oldb, oldc, oldd,
            a = 1732584193,
            b = -271733879,
            c = -1732584194,
            d = 271733878;

        for (i = 0; i < x.length; i += 16) {
            olda = a;
            oldb = b;
            oldc = c;
            oldd = d;

            a = md5_ff(a, b, c, d, x[i], 7, -680876936);
            d = md5_ff(d, a, b, c, x[i + 1], 12, -389564586);
            c = md5_ff(c, d, a, b, x[i + 2], 17, 606105819);
            b = md5_ff(b, c, d, a, x[i + 3], 22, -1044525330);
            a = md5_ff(a, b, c, d, x[i + 4], 7, -176418897);
            d = md5_ff(d, a, b, c, x[i + 5], 12, 1200080426);
            c = md5_ff(c, d, a, b, x[i + 6], 17, -1473231341);
            b = md5_ff(b, c, d, a, x[i + 7], 22, -45705983);
            a = md5_ff(a, b, c, d, x[i + 8], 7, 1770035416);
            d = md5_ff(d, a, b, c, x[i + 9], 12, -1958414417);
            c = md5_ff(c, d, a, b, x[i + 10], 17, -42063);
            b = md5_ff(b, c, d, a, x[i + 11], 22, -1990404162);
            a = md5_ff(a, b, c, d, x[i + 12], 7, 1804603682);
            d = md5_ff(d, a, b, c, x[i + 13], 12, -40341101);
            c = md5_ff(c, d, a, b, x[i + 14], 17, -1502002290);
            b = md5_ff(b, c, d, a, x[i + 15], 22, 1236535329);

            a = md5_gg(a, b, c, d, x[i + 1], 5, -165796510);
            d = md5_gg(d, a, b, c, x[i + 6], 9, -1069501632);
            c = md5_gg(c, d, a, b, x[i + 11], 14, 643717713);
            b = md5_gg(b, c, d, a, x[i], 20, -373897302);
            a = md5_gg(a, b, c, d, x[i + 5], 5, -701558691);
            d = md5_gg(d, a, b, c, x[i + 10], 9, 38016083);
            c = md5_gg(c, d, a, b, x[i + 15], 14, -660478335);
            b = md5_gg(b, c, d, a, x[i + 4], 20, -405537848);
            a = md5_gg(a, b, c, d, x[i + 9], 5, 568446438);
            d = md5_gg(d, a, b, c, x[i + 14], 9, -1019803690);
            c = md5_gg(c, d, a, b, x[i + 3], 14, -187363961);
            b = md5_gg(b, c, d, a, x[i + 8], 20, 1163531501);
            a = md5_gg(a, b, c, d, x[i + 13], 5, -1444681467);
            d = md5_gg(d, a, b, c, x[i + 2], 9, -51403784);
            c = md5_gg(c, d, a, b, x[i + 7], 14, 1735328473);
            b = md5_gg(b, c, d, a, x[i + 12], 20, -1926607734);

            a = md5_hh(a, b, c, d, x[i + 5], 4, -378558);
            d = md5_hh(d, a, b, c, x[i + 8], 11, -2022574463);
            c = md5_hh(c, d, a, b, x[i + 11], 16, 1839030562);
            b = md5_hh(b, c, d, a, x[i + 14], 23, -35309556);
            a = md5_hh(a, b, c, d, x[i + 1], 4, -1530992060);
            d = md5_hh(d, a, b, c, x[i + 4], 11, 1272893353);
            c = md5_hh(c, d, a, b, x[i + 7], 16, -155497632);
            b = md5_hh(b, c, d, a, x[i + 10], 23, -1094730640);
            a = md5_hh(a, b, c, d, x[i + 13], 4, 681279174);
            d = md5_hh(d, a, b, c, x[i], 11, -358537222);
            c = md5_hh(c, d, a, b, x[i + 3], 16, -722521979);
            b = md5_hh(b, c, d, a, x[i + 6], 23, 76029189);
            a = md5_hh(a, b, c, d, x[i + 9], 4, -640364487);
            d = md5_hh(d, a, b, c, x[i + 12], 11, -421815835);
            c = md5_hh(c, d, a, b, x[i + 15], 16, 530742520);
            b = md5_hh(b, c, d, a, x[i + 2], 23, -995338651);

            a = md5_ii(a, b, c, d, x[i], 6, -198630844);
            d = md5_ii(d, a, b, c, x[i + 7], 10, 1126891415);
            c = md5_ii(c, d, a, b, x[i + 14], 15, -1416354905);
            b = md5_ii(b, c, d, a, x[i + 5], 21, -57434055);
            a = md5_ii(a, b, c, d, x[i + 12], 6, 1700485571);
            d = md5_ii(d, a, b, c, x[i + 3], 10, -1894986606);
            c = md5_ii(c, d, a, b, x[i + 10], 15, -1051523);
            b = md5_ii(b, c, d, a, x[i + 1], 21, -2054922799);
            a = md5_ii(a, b, c, d, x[i + 8], 6, 1873313359);
            d = md5_ii(d, a, b, c, x[i + 15], 10, -30611744);
            c = md5_ii(c, d, a, b, x[i + 6], 15, -1560198380);
            b = md5_ii(b, c, d, a, x[i + 13], 21, 1309151649);
            a = md5_ii(a, b, c, d, x[i + 4], 6, -145523070);
            d = md5_ii(d, a, b, c, x[i + 11], 10, -1120210379);
            c = md5_ii(c, d, a, b, x[i + 2], 15, 718787259);
            b = md5_ii(b, c, d, a, x[i + 9], 21, -343485551);

            a = safe_add(a, olda);
            b = safe_add(b, oldb);
            c = safe_add(c, oldc);
            d = safe_add(d, oldd);
        }
        return [a, b, c, d];
    }

    /*
     * Convert an array of little-endian words to a string
     */
    function binl2rstr(input) {
        var i,
            output = '';
        for (i = 0; i < input.length * 32; i += 8) {
            output += String.fromCharCode((input[i >> 5] >>> (i % 32)) & 0xFF);
        }
        return output;
    }

    /*
     * Convert a raw string to an array of little-endian words
     * Characters >255 have their high-byte silently ignored.
     */
    function rstr2binl(input) {
        var i,
            output = [];
        output[(input.length >> 2) - 1] = undefined;
        for (i = 0; i < output.length; i += 1) {
            output[i] = 0;
        }
        for (i = 0; i < input.length * 8; i += 8) {
            output[i >> 5] |= (input.charCodeAt(i / 8) & 0xFF) << (i % 32);
        }
        return output;
    }

    /*
     * Calculate the MD5 of a raw string
     */
    function rstr_md5(s) {
        return binl2rstr(binl_md5(rstr2binl(s), s.length * 8));
    }

    /*
     * Calculate the HMAC-MD5, of a key and some data (raw strings)
     */
    function rstr_hmac_md5(key, data) {
        var i,
            bkey = rstr2binl(key),
            ipad = [],
            opad = [],
            hash;
        ipad[15] = opad[15] = undefined;
        if (bkey.length > 16) {
            bkey = binl_md5(bkey, key.length * 8);
        }
        for (i = 0; i < 16; i += 1) {
            ipad[i] = bkey[i] ^ 0x36363636;
            opad[i] = bkey[i] ^ 0x5C5C5C5C;
        }
        hash = binl_md5(ipad.concat(rstr2binl(data)), 512 + data.length * 8);
        return binl2rstr(binl_md5(opad.concat(hash), 512 + 128));
    }

    /*
     * Convert a raw string to a hex string
     */
    function rstr2hex(input) {
        var hex_tab = '0123456789abcdef',
            output = '',
            x,
            i;
        for (i = 0; i < input.length; i += 1) {
            x = input.charCodeAt(i);
            output += hex_tab.charAt((x >>> 4) & 0x0F) +
                hex_tab.charAt(x & 0x0F);
        }
        return output;
    }

    /*
     * Encode a string as utf-8
     */
    function str2rstr_utf8(input) {
        return unescape(encodeURIComponent(input));
    }

    /*
     * Take string arguments and return either raw or hex encoded strings
     */
    function raw_md5(s) {
        return rstr_md5(str2rstr_utf8(s));
    }

    function hex_md5(s) {
        return rstr2hex(raw_md5(s));
    }

    function raw_hmac_md5(k, d) {
        return rstr_hmac_md5(str2rstr_utf8(k), str2rstr_utf8(d));
    }

    function hex_hmac_md5(k, d) {
        return rstr2hex(raw_hmac_md5(k, d));
    }

    $.md5 = function (string, key, raw) {
        if (!key) {
            if (!raw) {
                return hex_md5(string);
            } else {
                return raw_md5(string);
            }
        }
        if (!raw) {
            return hex_hmac_md5(key, string);
        } else {
            return raw_hmac_md5(key, string);
        }
    };

}(typeof $razor === 'function' ? $razor : this));

// 变量定义
var event_bindings;
var $main = new Object();

(function(window, undefined){
    'use strict'
    var $razor = window.$razor;
    var $main = window.$main;

    $main.attrs = function(a, b, c){
        if(!a) return;
        if(!!c){
            var _att =document.createAttribute(b);
            _att.nodeValue = c;
            a.setAttributeNode(_att);
            return ;
        }
        if(!!a.getAttribute(b)){
            var _val = a.getAttributeNode(b).nodeValue;
            return _val;
        }else {
            return null;
        }
    };

    // browser浏览器信息
    window.browser = {
        versions: function() {
            var u = navigator.userAgent,
                app = navigator.appVersion;
            return {
                ios: !!u.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/),
                android: u.indexOf('Android') > -1 || u.indexOf('Linux') > -1,
                iPhone: u.indexOf('iPhone') > -1 || u.indexOf('Mac') > -1,
                iPad: u.indexOf('iPad') > -1
            };
        } (),
        language: (navigator.browserLanguage || navigator.language).toLowerCase()
    };
    // 函数定义
    $razor.getElementIdx = function (elt) {
        var count = 1;
        for (var sib = elt.previousSibling; sib; sib = sib.previousSibling) {
            if (sib.nodeType == 1 && sib.tagName == elt.tagName) count++;
        }
        return count;
    };

    // 获取ele的xPath
    $razor.getElementXPath = function (elt) {
        var path = '';
        for (; elt && elt.nodeType == 1; elt = elt.parentNode) {
            var idx = $razor.getElementIdx(elt);
            var xname = elt.tagName;
            var id = elt.getAttribute('id');
            if (id) {
                xname += "[@id='" + id + "']"
            }  else if (idx > 1) {
                xname += '[' + idx + ']'
            }
            path = '/' + xname + path;
        }
        return path;
    };

    // cookie的設置方法
    $main.setCookie = function(name,value, time){
        if(time){
            var exp = new Date();
            exp.setTime(exp.getTime() + time);
            document.cookie = name + "="+ escape (value) + ";expires="+exp.toGMTString();
        }else {
            document.cookie = name + "="+ escape (value) + ";expires=Fri, 31 Dec 9999 23:59:59 GMT";
        }
    };

    // 获取cookie值
    $main.getCookie = function(name){
        var arr,reg=new RegExp("(^| )"+name+"=([^;]*)(;|$)");
        if(arr=document.cookie.match(reg))
            return unescape(arr[2]);
        else
            return null;
    };

    // 删除cookie值
    $main.removeRazorCookie = function(name){
        $main.setCookie(name, '', -1);
    };

    // 创建元素的方法
    $main.createElement = function(str){
        var div1 = document.createElement("div");
        div1.innerHTML = str;
        var div2 = div1.childNodes[0];
        div2.appendTo = function (node){
            if(node){
                node.appendChild(div2);
            }
        }
        return div2;
    };
    $main.newDefinedBar = function(razorDefine){
        var definedBar = null;
        if(razorDefine){
            definedBar = '<div id="razor-nav1" class="razor-navbar"><div class="razor-navbar-inner">'
            +'<div class="razor-mode-control"><div class="razor-mode-switch">'
            +'<a class="razor-mode razor-mode-active" data-mode="definition">定义模式</a>'
            +'<a id="tnor" class="razor-mode" data-mode="normal" href="#">正常模式</a>'
            +'</div></div><div class="razor-ved-controls"><div class="razor-dropdown">'
            +'<a class="razor-dropdown-label razor-exit-link">退出</a></div></div>'
            +'<div class="razor-ved-controls"><div class="razor-dropdown">'
            +'<a class="razor-dropdown-label razor-exit-link">M</a>'
            +'</div></div>'
        } else {
            definedBar = '<div id="razor-nav1" class="razor-navbar"><div class="razor-navbar-inner">'
            +'<div class="razor-mode-control"><div class="razor-mode-switch">'
            +'<a class="razor-mode" data-mode="definition">定义模式</a><a id="tnor"'
            +' class="razor-mode razor-mode-active" data-mode="normal" href="#">正常模式</a>'
            +'</div></div><div class="razor-ved-controls"><div class="razor-dropdown">'
            +'<a class="razor-dropdown-label razor-exit-link">退出</a></div></div>'
            +'<div class="razor-ved-controls"><div class="razor-dropdown">'
            +'<a class="razor-dropdown-label razor-exit-link">M</a>'
            +'</div></div>'
        }
        return definedBar;
    }

    // 获取url的域名
    $razor.urlParam = function (name) {
        var results = new RegExp('[\?&#]*' + name + '=([^&#]*)').exec(window.location.href);
        if (results == null) {
            return null;
        } else {
            return results[1] || 0;
        }
    };

    // 圈选函数功能实现
    $razor.bindEvent = function (mode) {
        var $body = $razor('body');
        if (mode) {
            var elesRazor = $body.children().not('.razor-navbar')
                .not('.razor-tooltip').on('touchmove', function(event){
                    $body.find('.razor-tooltip').remove();
                    $body.find('.razor-outline-shade').remove();
                    $body.find('.razor-outline').remove();
                });

            elesRazor.each(function(index1, eles1){
                eles1.parentNode.addEventListener('click', function(event){
                    event.preventDefault();
                    if(event.target.innerHTML=="正常模式" || event.target.innerHTML=="定义模式" || event.target.innerHTML=="退出"
                        || event.target.innerHTML=="M") {
                    } else {
                        event.stopPropagation();
                        $body.find('.razor-tooltip').remove();
                        $body.find('.razor-outline-shade').remove();
                        var target = event.target;
                        if ($body.find('.razor-tooltip').length < 1) {
                            var target2 = window.getParentClickObj(target);
                            var target1 = window.getOnClickByParentObj(target2, target);
                            var actualTarget = target1 ? target1 : target2;
                            if (actualTarget) {
                                event.stopPropagation();

                                var width = $razor(actualTarget).width();
                                var height = $razor(actualTarget).innerHeight();
                                var offset = $razor(actualTarget).offset();
                                $body.find('.razor-outline').remove();
                                $razor('<div class="razor-outline" style="left: ' + offset.left + 'px' + ' !important; top: '
                                    + offset.top + 'px' + '!important; width: ' + width + 'px' + ' !important; max-width: '
                                    + width + 'px' + ' !important; height: 2px !important; max-height: 2px !important; '
                                    + 'white-space: pre-wrap !important; word-wrap: break-word !important;"></div>').appendTo($body);
                                $razor('<div class="razor-outline" style="left: ' + (offset.left + width) + 'px'
                                    + ' !important; top: ' + offset.top + 'px' + '!important; width: 2px !important; max-width: '
                                    + width + 'px' + ' !important; height: ' + height + 'px' + ' !important; max-height: '
                                    + height + 'px' + ' !important; white-space: pre-wrap !important; word-wrap: break-word '
                                    + '!important;"></div>').appendTo($body);
                                $razor('<div class="razor-outline" style="left: ' + offset.left + 'px' + ' !important; top: '
                                    + (offset.top + height) + 'px' + '!important; width: ' + width + 'px' + ' !important; max-width: '
                                    + width + 'px' + ' !important; height: 2px !important; max-height: 2px !important; '
                                    + 'white-space: pre-wrap !important; word-wrap: break-word !important;"></div>').appendTo($body);
                                $razor('<div class="razor-outline" style="left: ' + offset.left + 'px' + ' !important; top: '
                                    + offset.top + 'px' + '!important; width: 2px !important; max-width: ' + width + 'px'
                                    + ' !important; height: ' + height + 'px' + ' !important; max-height: ' + height
                                    + 'px' + ' !important; white-space: pre-wrap !important; word-wrap: break-word '
                                    + '!important;"></div>').appendTo($body);

                                var xpath = $razor.queryXpath(actualTarget);
                                for (var o in event_bindings) {
                                    var path = event_bindings[o].xpath;
                                    if (path == xpath) {
                                        //设置已绑定的值
                                        var $saveRegion_default = $razor('.razor-tooltip').find('.razor-tooltip-header')
                                            .find('.razor-sliding-views').find('.razor-tooltip-event-definition-region');
                                        $saveRegion_default.find('.event-en').val(event_bindings[o].event_identifier);
                                        $saveRegion_default.find('.event-cn').val(event_bindings[o].event_name);
                                    }
                                }

                                var realurl = window.location.href;

                                if(realurl.lastIndexOf("#")!=-1&&(realurl.length-1)==realurl.lastIndexOf("#")){
                                    realurl = realurl.substring(0,realurl.lastIndexOf("#"));
                                }
                                if(realurl.lastIndexOf("?")!=-1){
                                    realurl = realurl.substring(0,realurl.lastIndexOf("?"));
                                }
                                var argsRazor = '{"activity":"' + realurl + '","path":"' + xpath + '"}';

                                if (window.browser.versions.android){

                                    window.JsInject.bindEventNameByPath(argsRazor);
                                }

                                if (window.browser.versions.ios || window.browser.versions.iPhone || window.browser.versions.iPad){
                                    try {
                                        tianbai.bindEventNameByPath(argsRazor);
                                    } catch (e) {
                                    }
                                    try {
                                        window.webkit.messageHandlers.bindEvent.postMessage(argsRazor);
                                    } catch (e) {
                                    }
                                }
                            }
                        } else {
                            event.preventDefault();
                            event.stopPropagation();
                            $razor(target).on('click', function (tar) {
                                tar.stopPropagation();
                                tar.preventDefault();
                            });
                        }
                        event.stopPropagation();
                        return false;
                    }}, true);
                return false;
            })
        }
    };

    // 获取元素节点，封装成json字符串
    $razor.queryElement = function() {
        var msg = '';
        var e = e || window.event;
        var target = e.target || e.srcElement;
        var nodeName = target.nodeName;
        var id = target.getAttribute('id');
        var name = target.getAttribute('name');
        var xpath = '/' + $razor.getElementXPath(target).substring(10);
        msg += '{' + '"nodeName":"' + nodeName + '",' + '"id":"' + id + '",' + '"name":"'
            + name + '",' + '"xpath":"' + xpath + '"}';
        return msg;
    };

    // 查找事件的xPath信息
    $razor.queryXpath = function(target) {
        if(target){
            var xpath = '/' + $razor.getElementXPath(target).substring(10);
            return xpath;
        } else {
            var e = e || window.event;
            var target = e.target || e.srcElement;
            var xpath = '/' + $razor.getElementXPath(target).substring(10);
            return xpath;
        }
    };


    // 根据event的列表，实现元素圈选回放
    window.getEventBinds = function(event_list){
        event_bindings=event_list;
        //过滤已经绑定的事件
        for(var j in event_list){
            var path=event_list[j].xpath;
            //console.log(path);
            if(''!=path){
                var tem=_xpath(path);
                if(tem==null) continue;
                var rect=tem.getBoundingClientRect();
                var left=rect.left;
                var right=rect.right;
                var top=rect.top;
                var bottom=rect.bottom;
                var $body = $razor('body');
                $razor('<div class="razor-outline" style="left: ' + left + 'px' + ' !important; top: '
                    + top + 'px' + '!important; width: ' + (right-left) + 'px'
                    + ' !important; max-width: ' + (right-left) + 'px' + ' !important; height: 2px !important;'
                    +' max-height: 2px !important; white-space: pre-wrap !important; word-wrap:'
                    +' break-word !important;"></div>').appendTo($body);
                $razor('<div class="razor-outline" style="left: ' + right + 'px' + ' !important; top: '
                    + top + 'px' + '!important; width: 2px !important; max-width: ' + (right-left)
                    + 'px' + ' !important; height: ' + (bottom-top) + 'px' + ' !important; max-height: '
                    + (bottom-top) + 'px' + ' !important; white-space: pre-wrap !important; word-wrap:'
                    +' break-word !important;"></div>').appendTo($body);
                $razor('<div class="razor-outline" style="left: ' + left + 'px' + ' !important; top: '
                    + bottom + 'px' + '!important; width: ' + (right-left)
                    + 'px' + ' !important; max-width: ' + (right-left) + 'px'
                    + ' !important; height: 2px !important; max-height: 2px !important;'
                    +' white-space: pre-wrap !important; word-wrap: break-word !important;">'
                    +'</div>').appendTo($body);
                $razor('<div class="razor-outline" style="left: ' + left + 'px' + ' !important; top: '
                    + top + 'px' + '!important; width: 2px !important; max-width: ' + (right-left)
                    + 'px' + ' !important; height: ' + (bottom-top) + 'px' + ' !important; max-height: '
                    + (bottom-top) + 'px' + ' !important; white-space: pre-wrap !important;'
                    +' word-wrap: break-word !important;"></div>').appendTo($body);
            }
        }
    }

    window.removeRed = function (){
        var $body = $razor('body');
        $body.find('.razor-tooltip').remove();
        $body.find('.razor-outline-shade').remove();
        $body.find('.razor-outline').remove();
    }

    // 根据xPath查找元素
    window._xpath = function(STR_XPATH) {
        var xresult = document.evaluate('.'+STR_XPATH, document.body, null, XPathResult.ANY_TYPE, null);
        var xnodes = [];
        var xres;
        if(xres = xresult.iterateNext()) return xres;
        else return null;
    }

}(window));

// 完成加载执行函数
$razor(function () {
    var url = 'http://wapi.cobub.com/get/1.gif?';
    var eventUrl = "http://wapi.cobub.com/event/1.gif?";

    var params = {};
    //Document对象数据
    if (document) {
        params.domain = document.domain || '';
        params.url = document.URL || '';
        params.title = document.title || '';
        params.referrer = document.referrer || '';
    }
    //Window对象数据
    if (window && window.screen) {
        params.sh = window.screen.height || 0;
        params.sw = window.screen.width || 0;
        params.cd = window.screen.colorDepth || 0;
    }
    //navigator对象数据
    if (navigator) {
        params.lang = navigator.language || '';
    }

    window.$An = function (arr) {
        var event_name = arr[0];
        var category = arr[1];
        var action = arr[2];
        var opt_label = arr[3];
        var opt_value = arr[4];
        var img2 = new Image(1, 1);
        var str = 'eventname=' + encodeURI(event_name) +
            '&category=' + encodeURI(category) + '&action=' + encodeURI(action) +
            '&optlabel=' + encodeURI(opt_label) + '&optvalue=' + encodeURI(opt_value);
        //解析_maq配置
        if (_maq) {
            for (var i in _maq) {
                switch (_maq[i][0]) {
                    case '_setAccount':
                        str = str + '&account=' + encodeURI(_maq[i][1]);
                        break;
                    default:
                        break;
                }
            }
        }
        img2.src = eventUrl + str;
    };

    //解析_maq配置
    if (_maq) {
        for (var i in _maq) {
            switch (_maq[i][0]) {
                case '_setAccount':
                    params.account = _maq[i][1];
                    break;
                default:
                    break;
            }
        }
    }

    //拼接参数串
    var args = '';
    for (var i in params) {
        if (args != '') {
            args += '&';
        }
        args += i + '=' + encodeURIComponent(params[i]);
    }

    //通过Image对象请求后端脚本
    var img = new Image(1, 1);
    img.src = url + args;

    var debug = 1;
    var $body = $razor('body');
    var mode = true;
    if (debug == 1) {
        if (window.browser.versions.android){
            if($main.getCookie("razor_normal")=='true'){
                if($main.getCookie("razor_out")!='1'&&$main.getCookie("razor_out")!='2'){
                    var definedBar = $main.newDefinedBar(false);
                    $main.createElement(definedBar).appendTo($body.get(0));
                } else if($main.getCookie("razor_out")=='1'){
                    $main.setCookie("razor_out", '2');
                } else {
                    $main.removeRazorCookie('razor_out');
                    var definedBar = $main.newDefinedBar(false);
                    $main.createElement(definedBar).appendTo($body.get(0));
                }
                $razor.bindEvent(false);
            } else {
                if($main.getCookie("razor_out")!='1'&&$main.getCookie("razor_out")!='2'){
                    var definedBar = $main.newDefinedBar(true);
                    $main.createElement(definedBar).appendTo($body.get(0));
                    $razor.bindEvent(true);
                } else if($main.getCookie("razor_out")=='1'){
                    $main.setCookie("razor_out", '2');
                    $razor.bindEvent(false);
                } else {
                    var definedBar = $main.newDefinedBar(true);
                    $main.createElement(definedBar).appendTo($body.get(0));
                    $main.removeRazorCookie('razor_out');
                    $razor.bindEvent(true);
                }
            }
        }
        if(window.browser.versions.ios || window.browser.versions.iPhone || window.browser.versions.iPad){
            if($main.getCookie("razor_normal")=='true'){
                    if($main.getCookie("razor_out")!='1'&&$main.getCookie("razor_out")!='2'){
                        var definedBar = $main.newDefinedBar(false);
                        $main.createElement(definedBar).appendTo($body.get(0));
                    } else if($main.getCookie("razor_out")=='1'){
                        $main.setCookie("razor_out", '2');
                    } else {
                        var definedBar = $main.newDefinedBar(false);
                        $main.createElement(definedBar).appendTo($body.get(0));
                    $main.removeRazorCookie('razor_out');
                }
                $razor.bindEvent(false);
            } else {
                if($main.getCookie("razor_out")!='1'&&$main.getCookie("razor_out")!='2'){
                    var definedBar = $main.newDefinedBar(true);
                    $main.createElement(definedBar).appendTo($body.get(0));
                    $razor.bindEvent(true);
                } else if($main.getCookie("razor_out")=='1'){
                    $main.setCookie("razor_out", '2');
                    $razor.bindEvent(false);
                } else {
                    var definedBar = $main.newDefinedBar(true);
                    $main.createElement(definedBar).appendTo($body.get(0));
                    $main.removeRazorCookie('razor_out');
                    $razor.bindEvent(true);
                }
            }
        }

        var $swith = $body.children('.razor-navbar').find('.razor-navbar-inner')
            .find('.razor-mode-control').find('.razor-mode-switch').find('a.razor-mode');
        $swith.on('click', function (tar) {
            $razor(tar.target).addClass('razor-mode-active').siblings().removeClass('razor-mode-active');
            if ($razor(tar.target).data('mode') == 'definition') {
                $main.removeRazorCookie("razor_normal");
                $razor.bindEvent(true);
            } else if ($razor(tar.target).data('mode') == 'normal') {
                $main.setCookie("razor_normal", 'true');
                window.location.reload();
                $body.find('.razor-outline').remove();
                $razor.bindEvent(false);
            }
        });
        $body.children('.razor-navbar').find('.razor-navbar-inner').find('.razor-ved-controls')
            .find('.razor-dropdown').find('a.razor-dropdown-label.razor-exit-link')
            .on('click', function (event) {
                if(event.target.innerHTML == 'M'){
                    $razor('#razor-nav1').css("top", "51px");
                } else if(event.target.innerHTML == 'M') {
                    $razor('#razor-nav1').css("top", "0");
                } else {
                    $main.setCookie("razor_out", "1");
                    window.location.reload();
                }
            });
    }
    window.getQTag = function(tar){
        if(tar.tagName.toUpperCase()=="A"||tar.tagName.toUpperCase()=="BUTTON" || tar.tagName.toUpperCase()=="INPUT"
            || tar.tagName.toUpperCase()=="SELECT"||tar.tagName.toUpperCase()=="TEXTAREA"){
            return true;
        } else {
            return false;
        }
    }
    window.getParentClickObj = function(tar){
        var flag2 = window.isOnclickByJquery(tar);
        if(flag2){
            return tar;
        } else {
            var flag1 = window.getQTag(tar);
            if(flag1){
                return tar;
            }
            if((tar && tar.onclick) || (tar&&tar.getAttribute("onclick"))){
                return tar;
            } else {
                return window.getParentClickObj(tar.parentNode);
            }
        }
        return null;
    }

    window.isOnclickByJquery = function(tar){
        if(typeof jQuery != "undefined" || typeof $ != "undefined"){
            var $events = null;
            if($(tar)[0]){
                $events = $._data( $(tar)[0], "events" );
            }
            if($events && $events["click"] ){
                return true;
            } else {
                return false;
            }
        } else {
            return false;
        }
    }

    window.getOnClickByParentObj = function(pObj, tar){
        if(typeof jQuery != "undefined" || typeof $ != "undefined") {
            var cls = null;
            if($._data(pObj,"events") && $._data(pObj, "events").click) {
                var flag = false;
                cls = $._data(pObj, "events").click;
                $.each(cls, function(key, handlerObj){
                    var obj = (pObj.querySelector(""+handlerObj.selector));
                    if(obj==tar){
                        flag = true;
                    }
                });
                if (flag) {
                    return tar;
                } else {
                    if (tar.parentNode && (tar.parentNode != pObj)) {
                        return window.getOnClickByParentObj(pObj,tar.parentNode);
                    } else {
                        return pObj;
                    }
                }
            } 
        }
    }
});